@@ -21,7 +21,7 @@ package Apache2::AMF51DegreesFilter;
   use Apache2::Log;
   use Apache2::Filter (); 
   use APR::Table (); 
-  use LWP::Simple;
+  use LWP::Simple qw($ua get);
   use Apache2::Const -compile => qw(OK REDIRECT DECLINED);
   use IO::Uncompress::Gunzip qw(gunzip $GunzipError) ;  
   use constant BUFF_LEN => 1024;
@@ -81,6 +81,30 @@ package Apache2::AMF51DegreesFilter;
   $CommonLib->printLog("------- support http://groups.google.com/group/amf-device-detection -------");
   $CommonLib->printLog("---------------------------------------------------------------------------");
   $CommonLib->printLog("AMF51DegreesFilter module Version $VERSION");
+   if (($ENV{AMFSetProxy}) && $ENV{AMFSetProxy} eq 'true' ) {
+      $CommonLib->printLog("AMFSetHttpProxy is ".$ENV{AMFSetHttpProxy});
+      my $port=3128;
+      my $default="";
+      if ($ENV{AMFSetHttpProxyPort}) {
+            $port=$ENV{AMFSetHttpProxyPort};
+      } else {
+            $default=' (default)';
+      }
+      $CommonLib->printLog("AMFSetHttpProxyPort is ".$port.$default);
+      $ua->proxy('http','http://'.$ENV{AMFSetHttpProxy}.':'.$port);
+  }
+  my $timeoutinsecond=5;
+  my $default="";
+  if ($ENV{AMFSetGetParameterTimeoOut}) {
+       $timeoutinsecond=$ENV{AMFSetGetParameterTimeoOut};
+  } else {
+            $default=' (default)';
+  }
+       $CommonLib->printLog("AMFSetGetParameterTimeoOut is ".$timeoutinsecond.'s'.$default);
+  $ua->timeout($timeoutinsecond);
+  if ($ENV{AMFCheckVersion}) {
+	$checkVersion=$ENV{AMFCheckVersion};
+  }
   if ($ENV{AMFCheckVersion}) {
 	$checkVersion=$ENV{AMFCheckVersion};
   }
@@ -398,7 +422,7 @@ sub parse51DegreesFile {
 		 my $null="";
 		 my $null2="";
 		 my $null3="";
-		 my $ua="";
+		 my $uagent="";
 		 my $fb="";
 		 my $value="";
 		 my $id;
@@ -410,11 +434,11 @@ sub parse51DegreesFile {
 	     if ($record =~ /\<profile/o) {
                 my @field=split(/\"/, $record);
                 if ($field[5]) {
-                        $ua=lc($field[5]);
-			  if (index($ua,'blackberry') >-1 ) {
-			      $ua=substr($ua,index($ua,'blackberry'));
+                        $uagent=lc($field[5]);
+			  if (index($uagent,'blackberry') >-1 ) {
+			      $uagent=substr($uagent,index($uagent,'blackberry'));
 			  }
-			  ($ua,$version)=$CommonLib->androidDetection($ua);
+			  ($uagent,$version)=$CommonLib->androidDetection($uagent);
                 } 
 	        if ($field[1]) {
 	           $id=$field[1];
@@ -433,11 +457,11 @@ sub parse51DegreesFile {
 					$Array_fb{"$id"}=$fb;
 				 }
 				 if (($field[5]) && ($id)) {
-				         my %ParseUA=$CommonLib->GetMultipleUa($ua,$deepSearch);
+				         my %ParseUA=$CommonLib->GetMultipleUa($uagent,$deepSearch);
 				         my $pair;
 				         my $arrUaLen = scalar %ParseUA;
 				         my $contaUA=0;
-				         my $Array_fullua_id=$ua;
+				         my $Array_fullua_id=$uagent;
 				         foreach $pair (reverse sort { $a <=> $b }  keys %ParseUA) {
 						 	    my $dummy=$ParseUA{$pair};
 							    if ($Array_id{$dummy}) {} else {
@@ -503,7 +527,7 @@ sub IdentifyUAMethod {
   my $pair2;
   my $id_find="";
   my $dummy;
-  my $ua_toMatch;
+  my $uagent_toMatch;
   my $near_toFind=100;
   my $near_toMatch;
   my %ArrayUAType=$CommonLib->GetMultipleUa(lc($UserAgent),$deepSearch);  
