@@ -17,7 +17,7 @@ package Apache2::AMF51DegreesFilterMemcached;
   use Apache2::RequestRec ();
   use Apache2::RequestUtil ();
   use APR::Table (); 
-  use LWP::Simple;
+  use LWP::Simple qw($ua get);
   use Apache2::Const -compile => qw(DECLINED);
   use constant BUFF_LEN => 1024;
   use Cache::Memcached;
@@ -75,6 +75,30 @@ package Apache2::AMF51DegreesFilterMemcached;
   $CommonLib->printLog("------- support http://groups.google.com/group/amf-device-detection -------");
   $CommonLib->printLog("---------------------------------------------------------------------------");
   $CommonLib->printLog("AMF51DegreesFilterMemcached module Version $VERSION");
+   if (($ENV{AMFSetProxy}) && $ENV{AMFSetProxy} eq 'true' ) {
+      $CommonLib->printLog("AMFSetHttpProxy is ".$ENV{AMFSetHttpProxy});
+      my $port=3128;
+      my $default="";
+      if ($ENV{AMFSetHttpProxyPort}) {
+            $port=$ENV{AMFSetHttpProxyPort};
+      } else {
+            $default=' (default)';
+      }
+      $CommonLib->printLog("AMFSetHttpProxyPort is ".$port.$default);
+      $ua->proxy('http','http://'.$ENV{AMFSetHttpProxy}.':'.$port);
+  }
+  my $timeoutinsecond=5;
+  my $default="";
+  if ($ENV{AMFSetGetParameterTimeoOut}) {
+       $timeoutinsecond=$ENV{AMFSetGetParameterTimeoOut};
+  } else {
+            $default=' (default)';
+  }
+       $CommonLib->printLog("AMFSetGetParameterTimeoOut is ".$timeoutinsecond.'s'.$default);
+  $ua->timeout($timeoutinsecond);
+  if ($ENV{AMFCheckVersion}) {
+	$checkVersion=$ENV{AMFCheckVersion};
+  }
   if ($ENV{AMFCheckVersion}) {
 	$checkVersion=$ENV{AMFCheckVersion};
   }
@@ -124,7 +148,7 @@ package Apache2::AMF51DegreesFilterMemcached;
 	@Server = split(/,/, $ENV{ServerMemCached});
 	$CommonLib->printLog("ServerMemCached is: $serverMemCache");
    } else {
-	  $CommonLib->printLog("ServerMemCached is not setted. Please set the variable ServerMemCached into httpd.conf, example  \"PerlSetEnv ServerMemCached 10.10.10.10.:11211\"");
+	  $CommonLib->printLog("ServerMemCached is not setted. Please set the variable ServerMemCached into httpd.conf, example  \"PerlSetEnv ServerMemCached 10.10.10.10:11211\"");
 	  ModPerl::Util::exit();      
   }
   
@@ -371,7 +395,7 @@ sub IdentifyUAMethod {
   my $pair2;
   my $id_find="";
   my $dummy;
-  my $ua_toMatch;
+  my $uagent_toMatch;
   my $near_toFind=100;
   my $near_toMatch;
   my %ArrayUAType=$CommonLib->GetMultipleUa(lc($UserAgent),$deepSearch);
@@ -426,7 +450,7 @@ sub parse51DegreesFile {
 		 my $null="";
 		 my $null2="";
 		 my $null3="";
-		 my $ua="";
+		 my $uagent="";
 		 my $fb="";
 		 my $value="";
 		 my $id;
@@ -438,12 +462,12 @@ sub parse51DegreesFile {
 	     if ($record =~ /\<profile/o) {
                 my @field=split(/\"/, $record);
                 if ($field[5]) {
-                        $ua=lc($field[5]);
-			  if (index($ua,'blackberry') >-1 ) {
-			      $ua=substr($ua,index($ua,'blackberry'));
+                        $uagent=lc($field[5]);
+			  if (index($uagent,'blackberry') >-1 ) {
+			      $uagent=substr($uagent,index($uagent,'blackberry'));
 			  }
-			  ($ua,$version)=$CommonLib->androidDetection($ua);
-                        $ua=$CommonLib->CleanUa($ua);
+			  ($uagent,$version)=$CommonLib->androidDetection($uagent);
+                        $uagent=$CommonLib->CleanUa($uagent);
                 } 
 	        if ($field[1]) {
 	           $id=$field[1];
@@ -461,11 +485,11 @@ sub parse51DegreesFile {
 					$Array_fb{"$id"}=$fb;
 				 }
 				 if (($field[5]) && ($id)) {
-				         my %ParseUA=$CommonLib->GetMultipleUa($ua,$deepSearch);
+				         my %ParseUA=$CommonLib->GetMultipleUa($uagent,$deepSearch);
 				         my $pair;
 				         my $arrUaLen = scalar %ParseUA;
 				         my $contaUA=0;
-				         my $Array_fullua_id=$ua;
+				         my $Array_fullua_id=$uagent;
 				         foreach $pair (reverse sort { $a <=> $b }  keys %ParseUA) {
 						 	    my $dummy=$ParseUA{$pair};
 							    if ($Array_id{$dummy}) {} else {
