@@ -20,7 +20,7 @@ package Apache2::AMFDetectRightFilter;
   use Apache2::Log;
   use Apache2::Filter (); 
   use APR::Table (); 
-  use LWP::Simple;
+  use LWP::Simple qw($ua get);
   use Apache2::Const -compile => qw(OK REDIRECT DECLINED);
   use IO::Uncompress::Unzip qw(unzip $UnzipError) ;
   use constant BUFF_LEN => 1024;
@@ -66,6 +66,30 @@ package Apache2::AMFDetectRightFilter;
   $CommonLib->printLog("------- support http://groups.google.com/group/amf-device-detection -------");
   $CommonLib->printLog("---------------------------------------------------------------------------");
   $CommonLib->printLog("AMFDetectRightFilter module Version $VERSION");
+   if (($ENV{AMFSetProxy}) && $ENV{AMFSetProxy} eq 'true' ) {
+      $CommonLib->printLog("AMFSetHttpProxy is ".$ENV{AMFSetHttpProxy});
+      my $port=3128;
+      my $default="";
+      if ($ENV{AMFSetHttpProxyPort}) {
+            $port=$ENV{AMFSetHttpProxyPort};
+      } else {
+            $default=' (default)';
+      }
+      $CommonLib->printLog("AMFSetHttpProxyPort is ".$port.$default);
+      $ua->proxy('http','http://'.$ENV{AMFSetHttpProxy}.':'.$port);
+  }
+  my $timeoutinsecond=5;
+  my $default="";
+  if ($ENV{AMFSetGetParameterTimeoOut}) {
+       $timeoutinsecond=$ENV{AMFSetGetParameterTimeoOut};
+  } else {
+            $default=' (default)';
+  }
+       $CommonLib->printLog("AMFSetGetParameterTimeoOut is ".$timeoutinsecond.'s'.$default);
+  $ua->timeout($timeoutinsecond);
+  if ($ENV{AMFCheckVersion}) {
+	$checkVersion=$ENV{AMFCheckVersion};
+  }
   if ($ENV{AMFCheckVersion}) {
 	$checkVersion=$ENV{AMFCheckVersion};
   }
@@ -380,7 +404,7 @@ sub parseDetectRightFile {
 		 my $null="";
 		 my $null2="";
 		 my $null3="";
-		 my $ua="";
+		 my $uagent="";
 		 my $fb="";
 		 my $value="";
 		 my $id;
@@ -391,12 +415,12 @@ sub parseDetectRightFile {
 		 } 
 	     if ($record =~ /\<device/o) {
 	        if (index($record,'user_agent') > -1 ) {
-	           $ua=lc(substr($record,index($record,'user_agent') + 12,index($record,'"',index($record,'user_agent')+ 13)- index($record,'user_agent') - 12));
+	           $uagent=lc(substr($record,index($record,'user_agent') + 12,index($record,'"',index($record,'user_agent')+ 13)- index($record,'user_agent') - 12));
 
-			  if (index($ua,'blackberry') >-1 ) {
-					$ua=substr($ua,index($ua,'blackberry'));
+			  if (index($uagent,'blackberry') >-1 ) {
+					$uagent=substr($uagent,index($uagent,'blackberry'));
 			  }
-			  ($ua,$version)=$CommonLib->androidDetection($ua);
+			  ($uagent,$version)=$CommonLib->androidDetection($uagent);
 	        }	        
 	        if (index($record,'id') > -1 ) {
 	           $id=substr($record,index($record,'id') + 4,index($record,'"',index($record,'id')+ 5)- index($record,'id') - 4);	
@@ -407,12 +431,12 @@ sub parseDetectRightFile {
 	        if (($fb) && ($id)) {	     	   
 					$Array_fb{"$id"}=$fb;
 				 }
-				 if (($ua) && ($id)) {
-				         my %ParseUA=$CommonLib->GetMultipleUa($ua,$deepSearch);
+				 if (($uagent) && ($id)) {
+				         my %ParseUA=$CommonLib->GetMultipleUa($uagent,$deepSearch);
 				         my $pair;
 				         my $arrUaLen = scalar %ParseUA;
 				         my $contaUA=0;
-				         my $Array_fullua_id=$ua;
+				         my $Array_fullua_id=$uagent;
 				         foreach $pair (reverse sort { $a <=> $b }  keys %ParseUA) {
 						 	    my $dummy=$ParseUA{$pair};
 							    if ($Array_id{$dummy}) {} else {
@@ -478,7 +502,7 @@ sub IdentifyUAMethod {
   my $pair2;
   my $id_find="";
   my $dummy;
-  my $ua_toMatch;
+  my $uagent_toMatch;
   my $near_toFind=100;
   my $near_toMatch;
   my %ArrayUAType=$CommonLib->GetMultipleUa(lc($UserAgent),$deepSearch);  
