@@ -28,7 +28,7 @@ package Apache2::AMFMobileCachingMemcached;
   use IO::Uncompress::Unzip qw(unzip $UnzipError) ;
   use constant BUFF_LEN => 1024;
   use vars qw($VERSION);
-  $VERSION= "4.06";
+  $VERSION= "4.07";
   #
   # Define the global environment
   #
@@ -50,7 +50,7 @@ package Apache2::AMFMobileCachingMemcached;
 	@Server = split(/,/, $ENV{ServerMemCached});
 	$CommonLib->printLog("ServerMemCached is: $serverMemCache");
    } else {
-	  $CommonLib->printLog("ServerMemCached is not setted. Please set the variable ServerMemCached into httpd.conf, example  \"PerlSetEnv ServerMemCached 10.10.10.10.:11211\"");
+	  $CommonLib->printLog("ServerMemCached is not setted. Please set the variable ServerMemCached into httpd.conf, example  \"PerlSetEnv ServerMemCached 10.10.10.10:11211\"");
 	  ModPerl::Util::exit();      
   }
   
