@@ -16,7 +16,7 @@ package Apache2::AMFWURFLFilterMemcached;
   use Apache2::RequestRec ();
   use Apache2::RequestUtil ();
   use APR::Table (); 
-  use LWP::Simple;
+  use LWP::Simple qw($ua get);
   use Apache2::Const -compile => qw(DECLINED);
   use constant BUFF_LEN => 1024;
   use Cache::Memcached;
@@ -65,6 +65,30 @@ package Apache2::AMFWURFLFilterMemcached;
   $CommonLib->printLog("--- For more info: http://www.scientiamobile.com.                       ---");
   $CommonLib->printLog("---------------------------------------------------------------------------");
   $CommonLib->printLog("AMFWURFLFilterMemcached module Version $VERSION");
+   if (($ENV{AMFSetProxy}) && $ENV{AMFSetProxy} eq 'true' ) {
+      $CommonLib->printLog("AMFSetHttpProxy is ".$ENV{AMFSetHttpProxy});
+      my $port=3128;
+      my $default="";
+      if ($ENV{AMFSetHttpProxyPort}) {
+            $port=$ENV{AMFSetHttpProxyPort};
+      } else {
+            $default=' (default)';
+      }
+      $CommonLib->printLog("AMFSetHttpProxyPort is ".$port.$default);
+      $ua->proxy('http','http://'.$ENV{AMFSetHttpProxy}.':'.$port);
+  }
+  my $timeoutinsecond=5;
+  my $default="";
+  if ($ENV{AMFSetGetParameterTimeoOut}) {
+       $timeoutinsecond=$ENV{AMFSetGetParameterTimeoOut};
+  } else {
+            $default=' (default)';
+  }
+       $CommonLib->printLog("AMFSetGetParameterTimeoOut is ".$timeoutinsecond.'s'.$default);
+  $ua->timeout($timeoutinsecond);
+  if ($ENV{AMFCheckVersion}) {
+	$checkVersion=$ENV{AMFCheckVersion};
+  }
   if ($ENV{AMFCheckVersion}) {
 	$checkVersion=$ENV{AMFCheckVersion};
   }
@@ -120,7 +144,7 @@ my $memd = new Cache::Memcached {
         $memd->set_servers(\@Server);
 	$CommonLib->printLog("ServerMemCached is: $serverMemCache");
    } else {
-	  $CommonLib->printLog("ServerMemCached is not setted. Please set the variable ServerMemCached into httpd.conf, example  \"PerlSetEnv ServerMemCached 10.10.10.10.:11211\"");
+	  $CommonLib->printLog("ServerMemCached is not setted. Please set the variable ServerMemCached into httpd.conf, example  \"PerlSetEnv ServerMemCached 10.10.10.10:11211\"");
 	  ModPerl::Util::exit();      
   }
   
@@ -366,7 +390,7 @@ sub IdentifyUAMethod {
   my $pair2;
   my $id_find="";
   my $dummy;
-  my $ua_toMatch;
+  my $uagent_toMatch;
   my $near_toFind=100;
   my $near_toMatch;
   my %ArrayUAType=$CommonLib->GetMultipleUa(lc($UserAgent),$deepSearch);
@@ -425,7 +449,7 @@ sub parseWURFLFile {
 		 my $null="";
 		 my $null2="";
 		 my $null3="";
-		 my $ua="";
+		 my $uagent="";
 		 my $fb="";
 		 my $value="";
 		 my $id;
@@ -437,11 +461,11 @@ sub parseWURFLFile {
 		 } 
 	     if ($record =~ /\<device/o) {
 	        if (index($record,'user_agent') > -1 ) {
-	           $ua=lc(substr($record,index($record,'user_agent') + 12,index($record,'"',index($record,'user_agent')+ 13)- index($record,'user_agent') - 12));
-			  if (index($ua,'blackberry') > -1 ) {
-					$ua=substr($ua,index($ua,'blackberry'));
+	           $uagent=lc(substr($record,index($record,'user_agent') + 12,index($record,'"',index($record,'user_agent')+ 13)- index($record,'user_agent') - 12));
+			  if (index($uagent,'blackberry') > -1 ) {
+					$uagent=substr($uagent,index($uagent,'blackberry'));
 			  }
-			  ($ua,$version)=$CommonLib->androidDetection($ua);
+			  ($uagent,$version)=$CommonLib->androidDetection($uagent);
 	        }	        
 	        if (index($record,'id') > 0 ) {
 	           $id=substr($record,index($record,'id') + 4,index($record,'"',index($record,'id')+ 5)- index($record,'id') - 4);
@@ -452,12 +476,12 @@ sub parseWURFLFile {
 	        if (($fb) && ($id)) {	     	   
 					$Array_fb{"$id"}=$fb;
 				 }
-				 if (($ua) && ($id)) {
-				         my %ParseUA=$CommonLib->GetMultipleUa($ua,$deepSearch);
+				 if (($uagent) && ($id)) {
+				         my %ParseUA=$CommonLib->GetMultipleUa($uagent,$deepSearch);
 				         my $pair;
 				         my $arrUaLen = scalar %ParseUA;
 				         my $contaUA=0;
-				         my $Array_fullua_id=$ua;
+				         my $Array_fullua_id=$uagent;
 				         foreach $pair (reverse sort { $a <=> $b }  keys %ParseUA) {
 						 	my $dummy=$ParseUA{$pair};
 							if ($Array_id{$dummy}) {} else {
